<?php
/*
 * copyright (c) 2010 MDBitz - Matthew John Denton - mdbitz.com
 *
 * This file is part of WordPress Amazon Associate Plugin.
 *
 * WordPress Amazon Associate is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * WordPress Amazon Associate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WordPress Amazon Associate.
 * If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * BasicWidget
 *
 * This file contains the class BasicWidget
 *
 * @author Matthew John Denton <matt@mdbitz.com>
 * @package com.mdbitz.wordpress.amazon_associate
 */

/**
 * BasicWidget is a proof of concept wordpress widget
 *
 * @package com.mdbitz.wordpress.amazon_associate.widget
 */
class BasicWidget extends WP_Widget {

    /**
     * constructor
     */
    function BasicWidget() {
        /* Widget Settings */
        $widget_settings = array( 'classname'=>'BasicWidget', 'description'=>'Amazon Product Widget' );
        /* Widget Control Options */
        $widget_options = array( 'width' => 300, 'height' => 350, 'id_base' => 'basic-widget' );

        parent::WP_Widget('basic-widget', 'Basic Amazon Widget', $widget_ops, $control_ops);
    }

    /**
     * @see WP_Widget::widget
     */
    function widget($args, $instance) {
        global $wpaaAdmin;
        $api = $wpaaAdmin->getAPI();
        $result = $api->similarityLookup( $instance['asin'], AmazonProduct_ResponseGroup::SMALL, AmazonProduct_SimilarityType::RANDOM );
        // output widgets only if Amazon successfully returned a product
        if( $result->isSuccess() ) {
            extract( $args );
            $title = apply_filters('widget_title', $instance['title']);
            echo $before_widget;
            if ( $title ) {
                echo $before_title . $title . $after_title;
            }
            // Product Output
            $randKey = array_rand( $result->Items );
            $product_asin = $result->Items[$randKey]->ASIN;
            $result = $api->lookupByASIN( $product_asin, array(AmazonProduct_ResponseGroup::SMALL, AmazonProduct_ResponseGroup::IMAGES) );

            $product = $result->Items[0];
            echo '<a href="' . $product->DetailPageURL . '" target="_blank">';
            if( is_null($product->MediumImage) ) {
                echo $product->ItemAttributes->Title;
            } else {
                echo $product->MediumImage->toHTML();
            }
            echo '</a>';

            echo $after_widget;
        }
    }

    /**
     * @see WP_Widget::update
     */
    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['asin'] = strip_tags($new_instance['asin']);
        return $instance;
    }

    /**
     * @see WP_Widget::form
     */
    function form($instance) {
        $title = esc_attr($instance['title']);
        $asin = esc_attr($instance['asin']);
        ?>
<p>
    <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label>
    <label for="<?php echo $this->get_field_id('asin'); ?>"><?php _e('Product ASIN:'); ?> <input class="widefat" id="<?php echo $this->get_field_id('asin'); ?>" name="<?php echo $this->get_field_name('asin'); ?>" type="text" value="<?php echo $asin; ?>" /></label>
</p>
        <?php
    }

} // class BasicWidget